SPAppBar class

A platform-adaptive Sixplace application bar.

Android, web and desktop use Material styling. iOS automatically receives iOS navigation-bar styling.

Inheritance
Implemented types

Constructors

SPAppBar({Key? key, required String title, Widget? titleWidget, Widget? leading, List<Widget>? actions, bool automaticallyImplyLeading = true, bool showDrawerIcon = false, VoidCallback? onDrawerPressed, bool? centerTitle, PreferredSizeWidget? bottom, Color? backgroundColor, Color? foregroundColor, Color? shadowColor, Color? surfaceTintColor, TextStyle? titleTextStyle, ShapeBorder? shape, double? toolbarHeight, double? leadingWidth, double? elevation = 0, double? scrolledUnderElevation, bool adaptive = true, TargetPlatform? platform})
const

Properties

actions List<Widget>?
final
adaptive bool
Enables automatic platform styling.
final
automaticallyImplyLeading bool
final
backgroundColor Color?
final
bottom PreferredSizeWidget?
final
centerTitle bool?
When null:
final
elevation double?
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
final
leadingWidth double?
final
onDrawerPressed VoidCallback?
final
platform TargetPlatform?
Mainly useful for testing or previewing another platform.
final
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrolledUnderElevation double?
final
shadowColor Color?
final
shape ShapeBorder?
final
showDrawerIcon bool
final
surfaceTintColor Color?
final
title String
final
titleTextStyle TextStyle?
final
titleWidget Widget?
final
toolbarHeight double?
When null:
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited