SPContainerWidths class

Maximum widths used by a fixed SPContainer.

Annotations

Constructors

SPContainerWidths({double sm = 540, double md = 720, double lg = 960, double xl = 1140, double xxl = 1320})
Defaults match Bootstrap 5 container widths.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
lg double
final
md double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
final
xl double
final
xxl double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double width, {SPBreakpoints breakpoints = SPBreakpoints.standard}) double
Resolves the maximum container width for the available parent width.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

bootstrap → const SPContainerWidths