SPResponsiveSizedBox class
A SizedBox whose width and height can change by viewport breakpoint.
Values are automatically resolved using the current viewport width. Application code does not need to read MediaQuery or manually call SPResponsiveValue.resolve.
Example:
SPResponsiveSizedBox(
height: const SPResponsiveValue<double?>(
base: null,
lg: 350,
),
child: chart,
)
A resolved null width or height behaves exactly like a null width or height on Flutter's native SizedBox.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SPResponsiveSizedBox
Constructors
-
SPResponsiveSizedBox({Key? key, SPResponsiveValue<
double?> ? width, SPResponsiveValue<double?> ? height, SPBreakpoints breakpoints = SPBreakpoints.standard, Widget? child}) -
const
Properties
- breakpoints → SPBreakpoints
-
Breakpoints used to resolve width and height.
final
- child → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
height
→ SPResponsiveValue<
double?> ? -
Responsive height.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
width
→ SPResponsiveValue<
double?> ? -
Responsive width.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited