SPRow class

Places responsive SPCol widgets inside a twelve-column wrapping row.

Responsive decisions use the immediate parent's available width instead of the entire device screen width.

Inheritance

Constructors

SPRow({Key? key, required List<SPCol> children, double gap = 0, double? horizontalGap, double? verticalGap, SPResponsiveValue<double>? responsiveGap, SPBreakpoints breakpoints = SPBreakpoints.standard, WrapAlignment alignment = WrapAlignment.start, WrapAlignment runAlignment = WrapAlignment.start, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Clip clipBehavior = Clip.none})
const

Properties

alignment WrapAlignment
final
breakpoints SPBreakpoints
final
children List<SPCol>
final
clipBehavior Clip
final
crossAxisAlignment WrapCrossAlignment
final
gap double
Static shorthand value for horizontal and vertical gaps.
final
hashCode int
The hash code for this object.
no setterinherited
horizontalGap double
Static horizontal space between visible column contents.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
responsiveGap SPResponsiveValue<double>?
Optional responsive shorthand for horizontal and vertical gaps.
final
runAlignment WrapAlignment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textDirection TextDirection?
final
verticalDirection VerticalDirection
final
verticalGap double
Static vertical space between wrapped rows.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited