SPContainerWidths class
Maximum widths used by a fixed SPContainer.
- Annotations
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
double width, {SPBreakpoints breakpoints = SPBreakpoints.standard}) → double - Resolves the maximum container width for the available parent width.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- bootstrap → const SPContainerWidths