SPResponsiveValue<T> class
Stores one value that can change across responsive breakpoints.
Missing values inherit from the nearest configured smaller breakpoint.
- Available extensions
- Annotations
Constructors
- SPResponsiveValue({required T base, T? sm, T? md, T? lg, T? xl, T? xxl})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
double width, {SPBreakpoints breakpoints = SPBreakpoints.standard}) → T - Resolves the value using the supplied available width.
-
resolveBreakpoint(
SPBreakpoint breakpoint) → T - Resolves the value using an already known breakpoint.
-
resolveFrom(
BuildContext context, {SPBreakpoints breakpoints = SPBreakpoints.standard}) → T -
Available on SPResponsiveValue<
Resolves this value using the current viewport width.T> , provided by the SPResponsiveValueBuildContext extension -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override